# The Mathematics Package 0.0.0a1
[![CI](https://github.com/arihant2math/mathematics/actions/workflows/test.yml/badge.svg)](https://github.com/arihant2math/mathematics/actions/workflows/test.yml)
[![Documentation Status](https://readthedocs.org/projects/mathematics-package/badge/?version=latest)](https://mathematics-package.readthedocs.io/en/latest/?badge=latest)

This package has been made to assist mathematicians, with a number theory, counting, probability, statistics, and algebra 
module.
